/*
Copyright (c) 2013-2019, Technolution B.V.
 All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this 
   list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice, this 
   list of conditions and the following disclaimer in the documentation and/or 
   other materials provided with the distribution.

3. Neither the name of Technolution nor the names of its contributors may be used 
   to endorse or promote products derived from this software without specific 
   prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, 
OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
POSSIBILITY OF SUCH DAMAGE.
*/
package org.disperanto.displaysimulator.data;

import java.nio.ByteBuffer;
import java.util.ArrayList;
import java.util.HashMap;

import org.disperanto.data.TdpDisplayProperties;
import org.disperanto.data.TdpStatus;
import org.disperanto.enums.ETdpDisplayType;

public class DisplayCreator {

    public Display createDisplay(int address) {
        TdpDisplayProperties properties = initDisplayProperties();
        TdpStatus status = initStatus();
        return new Display(address, properties, status);
    }

    private TdpDisplayProperties initDisplayProperties() {
        final ByteBuffer rgbColor = ByteBuffer.allocate(3);
        rgbColor.put((byte)0xFF);
        rgbColor.put((byte)0xFF);
        rgbColor.put((byte)0xFF);

        final TdpDisplayProperties properties = new TdpDisplayProperties();
        properties.setProtocolVersion(1);
        properties.setDisplayType(ETdpDisplayType.MATRIX);
        properties.setSupplierAndProductType("S&P info");
        properties.setSerialNumber("serialnumber1.0");
        properties.setSoftwareVersion("software v2.3");
        properties.setExternalLighting(true);
        properties.setDisplayHeightInPixels(180);
        properties.setDisplayWidthInPixels(192);
        properties.setNrFixedImages(0);
        properties.setNrWritableImages(9);
        properties.setSlideShow(true);
        properties.setRgbColors(rgbColor);
        properties.setPngSupported(true);
        properties.setTextDisplayRows(3);
        properties.setTextDisplayColumns(30);
        return properties;
    }

    private TdpStatus initStatus() {
        final TdpStatus status = new TdpStatus();
        status.setShownImages(new HashMap<Integer, Short>()); // empty map
        status.setBrightnessInPercentage(75);
        status.setIntensityExternalLighting(null);
        status.setMeasuredLightIntensity(new ArrayList<Integer>()); // empty list
        status.setGpsPosition("5.659,51.480");
        status.setTemperature(23);
        status.setHeating(1);
        status.setCooling(0);
        return status;
    }

}
