/*
Copyright (c) 2013, Technolution B.V.
 All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this 
   list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice, this 
   list of conditions and the following disclaimer in the documentation and/or 
   other materials provided with the distribution.

3. Neither the name of Technolution nor the names of its contributors may be used 
   to endorse or promote products derived from this software without specific 
   prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, 
OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
POSSIBILITY OF SUCH DAMAGE.
*/
package org.disperanto.displaysimulator.ui.controllers;

import org.disperanto.data.TdpTimeoutSettings;
import org.disperanto.displaysimulator.data.DisplayController;
import org.disperanto.displaysimulator.listeners.ICommunicationSettingsListener;
import org.disperanto.displaysimulator.listeners.IDisplayControllerListener;
import org.disperanto.displaysimulator.ui.panels.CommunicationTimeoutPanel;
import org.disperanto.enums.ETdpTimeoutMode;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * View controller for CommunicationTimeoutPanel.
 */
public class CommunicationTimeoutViewController implements IDisplayControllerListener, ICommunicationSettingsListener {
    private static final Logger LOG = LoggerFactory.getLogger(CommunicationTimeoutViewController.class);

    private CommunicationTimeoutPanel panel;
    private DisplayController controller;
    private int displayAddress;

    /**
     * Constructor
     * 
     * @param panel Panel that is controlled
     * @param controller Display controller
     */
    public CommunicationTimeoutViewController(CommunicationTimeoutPanel panel, DisplayController controller) {
        this.panel = panel;
        this.controller = controller;
    }

    @Override
    public void displayChanged(int activeDisplay) {
        LOG.debug("Settings changed");

        displayAddress = activeDisplay;
        settingsChanged(displayAddress, controller.getDisplay(displayAddress).getTimeoutSettings());
    }

    @Override
    public final void settingsChanged(int displayAddress, TdpTimeoutSettings settings) {
        if (displayAddress != this.displayAddress) {
            // change for display that is not shown. Ignore.
            return;
        }

        panel.getModeField().setText(settings.getTimeoutMode().getDescription());

        if (settings.getTimeoutMode() != ETdpTimeoutMode.NO_TIMEOUT) {
            panel.getTimeoutLabel().setVisible(true);
            panel.getTimeoutField().setVisible(true);
            panel.getTimeoutField().setText("" + settings.getTimeoutInSec());
        } else {
            panel.getTimeoutLabel().setVisible(false);
            panel.getTimeoutField().setVisible(false);
        }

        if (settings.getTimeoutMode() == ETdpTimeoutMode.SHOW_IMAGE) {
            panel.getImageSlotLabel().setVisible(true);
            panel.getImageSlotField().setVisible(true);
            panel.getImageSlotField().setText("" + settings.getImageSlot());
        } else {
            panel.getImageSlotLabel().setVisible(false);
            panel.getImageSlotField().setVisible(false);
        }
    }
}
