/*
Copyright (c) 2013, Technolution B.V.
 All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this 
   list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice, this 
   list of conditions and the following disclaimer in the documentation and/or 
   other materials provided with the distribution.

3. Neither the name of Technolution nor the names of its contributors may be used 
   to endorse or promote products derived from this software without specific 
   prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, 
OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
POSSIBILITY OF SUCH DAMAGE.
*/
package org.disperanto.displaysimulator.ui.controllers;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JOptionPane;

import org.disperanto.communication.IStartableConnection;
import org.disperanto.displaysimulator.data.DisplayController;
import org.disperanto.displaysimulator.ui.panels.DisplayControllerPanel;
import org.disperanto.enums.EIpConnectionType;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * View controller for DisplayControllerPanel.
 */
public class DisplayControllerViewController implements ActionListener {
    private static final Logger LOG = LoggerFactory.getLogger(DisplayControllerViewController.class);

    private final DisplayControllerPanel panel;
    private final DisplayController controller;

    /**
     * Constructor
     *
     * @param panel Panel that is controlled
     * @param controller Display controller
     */
    public DisplayControllerViewController(DisplayControllerPanel panel, DisplayController controller) {
        this.panel = panel;
        this.controller = controller;

        // initialize connection
        setConnection();
    }

    @Override
    public final void actionPerformed(ActionEvent arg0) {
        LOG.debug("Apply button pressed");

        if (!validate()) {
            return;
        }

        setConnection();
    }

    private boolean validate() {
        if (panel.getReceivePort().getText().equals("")) {
            JOptionPane.showMessageDialog(panel.getRootPane(), "Receive port is mandatory");
            return false;
        }

        if ((panel.getConnectionType() == EIpConnectionType.UDP) && (panel.getTimeout().getText().equals(""))) {
            JOptionPane.showMessageDialog(panel.getRootPane(), "Timeout is mandatory for UDP");
            return false;
        }

        return true;
    }

    private void setConnection() {
        final IStartableConnection connection = panel.getConnection();
        controller.setConnection(connection);
    }
}
