/*
Copyright (c) 2013, Technolution B.V.
 All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this 
   list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice, this 
   list of conditions and the following disclaimer in the documentation and/or 
   other materials provided with the distribution.

3. Neither the name of Technolution nor the names of its contributors may be used 
   to endorse or promote products derived from this software without specific 
   prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, 
OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
POSSIBILITY OF SUCH DAMAGE.
*/
package org.disperanto.displaysimulator.ui.controllers;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JOptionPane;

import org.disperanto.data.TdpDisplayProperties;
import org.disperanto.displaysimulator.data.DisplayController;
import org.disperanto.displaysimulator.listeners.IDisplayControllerListener;
import org.disperanto.displaysimulator.ui.models.PropertiesModel;
import org.disperanto.displaysimulator.ui.panels.PropertiesPanel;
import org.disperanto.enums.ETdpDisplayType;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * View controller for DisplayPropertiesPanel.
 */
public class PropertiesViewController implements ActionListener, IDisplayControllerListener {
    private static final Logger LOG = LoggerFactory.getLogger(PropertiesViewController.class);

    private PropertiesModel model;
    private PropertiesPanel panel;
    private DisplayController controller;
    private int displayAddress;

    /**
     * Constructor
     * 
     * @param panel Panel that is controlled
     * @param model Model of panel
     * @param controller Display controller
     */
    public PropertiesViewController(PropertiesPanel panel, PropertiesModel model, DisplayController controller) {
        this.model = model;
        this.panel = panel;
        this.controller = controller;
    }

    private void initModel(int displayAddress, TdpDisplayProperties properties) {
        model.setProperties(displayAddress, properties);
    }

    @Override
    public final void actionPerformed(ActionEvent arg0) {
        LOG.debug("Save button pressed");

        if (!validate()) {
            return;
        }

        setProperties();
    }

    private boolean validate() {
        if (panel.getRgbColorsCheck().isSelected() && panel.getFixedColorPaletteCheck().isSelected()) {
            JOptionPane.showMessageDialog(panel.getRootPane(),
                    "Select rgbColors or fixedColorPallete, but do not select both");
            return false;
        }

        if (!panel.getRgbColorsCheck().isSelected() && !panel.getFixedColorPaletteCheck().isSelected()) {
            JOptionPane.showMessageDialog(panel.getRootPane(),
                    "Select rgbColors or fixedColorPallete, but do not select none");
            return false;
        }

        return true;
    }

    private void setProperties() {
        final TdpDisplayProperties properties = model.getProperties();

        properties.setProtocolVersion((int)panel.getProtocolField().getValue());
        properties.setDisplayType((ETdpDisplayType)panel.getDisplayTypeField().getSelectedItem());
        properties.setSupplierAndProductType(panel.getSupplierAndProductField().getText());
        properties.setSerialNumber(panel.getSerialField().getText());
        properties.setSoftwareVersion(panel.getSoftwareVersionField().getText());
        properties.setExternalLighting(panel.getExternalLightingCheck().isSelected());
        properties.setDisplayHeightInPixels((int)panel.getDisplayHeightField().getValue());
        properties.setDisplayWidthInPixels((int)panel.getDisplayWidthField().getValue());
        properties.setNrFixedImages((int)panel.getNumberFixedImagesField().getValue());
        properties.setNrWritableImages((int)panel.getNumberWritableImagesField().getValue());
        properties.setSlideShow(panel.getSlideShowCheck().isSelected());
        // properties.setRgbColors(panel.getRgbColorsCheck().getText());
        // properties.setFixedColorPalette(panel.getSlideShowCheck().isSelected());
        properties.setPngSupported(panel.getPngSupportedCheck().isSelected());
        properties.setTextDisplayRows((int)panel.getTextDisplayColumnsField().getValue());
        properties.setTextDisplayColumns((int)panel.getTextDisplayRowsField().getValue());

        // copy object to display
        controller.getDisplay(displayAddress).setDisplayProperties(new TdpDisplayProperties(properties));

        model.setProperties(displayAddress, properties);
    }

    @Override
    public final void displayChanged(int activeDisplay) {
        displayAddress = activeDisplay;

        // init model: copy initial values from display
        initModel(displayAddress,
                new TdpDisplayProperties(controller.getDisplay(displayAddress).getDisplayProperties()));
    }
}

