/*
Copyright (c) 2013, Technolution B.V.
 All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this 
   list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice, this 
   list of conditions and the following disclaimer in the documentation and/or 
   other materials provided with the distribution.

3. Neither the name of Technolution nor the names of its contributors may be used 
   to endorse or promote products derived from this software without specific 
   prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, 
OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
POSSIBILITY OF SUCH DAMAGE.
*/
package org.disperanto.displaysimulator.ui.models;

import java.util.ArrayList;
import java.util.List;

import org.disperanto.data.TdpNotification;
import org.disperanto.displaysimulator.listeners.INotificationListener;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Model for panel with notifications.
 */
public class NotificationModel {
    private static final Logger LOG = LoggerFactory.getLogger(NotificationModel.class);

    private int displayAddress;
    private List<TdpNotification> notificationList = new ArrayList<TdpNotification>();
    private List<INotificationListener> listeners = new ArrayList<INotificationListener>();

    /**
     * Constructor
     */
    public NotificationModel() {

    }

    /**
     * @return the properties
     */
    public final List<TdpNotification> getNotifications() {
        return notificationList;
    }

    /**
     * @param notificationList the notificationList to set
     */
    public final void setNotifications(List<TdpNotification> notificationList) {
        this.notificationList = notificationList;

        fireChange(displayAddress, notificationList);
    }

    /**
     * @param listener Listener of changes in notifications
     */
    public final void addListener(INotificationListener listener) {
        listeners.add(listener);
    }

    /**
     * fires notification for listeners.
     * 
     * @param displayAddress Address of display
     * @param notificationList List of notifications
     */
    public final void fireChange(int displayAddress, List<TdpNotification> notificationList) {
        LOG.debug("Fire change");
        for (INotificationListener listener : listeners) {
            listener.notificationsChanged(displayAddress, notificationList);
        }
    }
}
