/*
Copyright (c) 2013, Technolution B.V.
 All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this 
   list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice, this 
   list of conditions and the following disclaimer in the documentation and/or 
   other materials provided with the distribution.

3. Neither the name of Technolution nor the names of its contributors may be used 
   to endorse or promote products derived from this software without specific 
   prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, 
OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
POSSIBILITY OF SUCH DAMAGE.
*/
package org.disperanto.displaysimulator.ui.panels;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.image.BufferedImage;

import javax.swing.JLabel;
import javax.swing.JPanel;

import net.miginfocom.swing.MigLayout;

import org.disperanto.data.TdpDisplayProperties;
import org.disperanto.displaysimulator.listeners.IImageListener;
import org.disperanto.displaysimulator.listeners.IPropertiesListener;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Panel to preview a font.
 */
public class FontPreviewPanel extends JPanel implements IPropertiesListener, IImageListener {
    private static final Logger LOG = LoggerFactory.getLogger(FontPreviewPanel.class);

    private int displayWidth = 1;
    private int displayHeight = 1;
    private final InternalPreviewPanel ipp;

    private final JLabel displayEnabledLabel;
    private boolean isDisplayEnabled;
    private BufferedImage image;

    public FontPreviewPanel() {
        setLayout(new MigLayout());

        ipp = new InternalPreviewPanel();
        add(ipp, "grow, wrap, span");

        displayEnabledLabel = new JLabel();
        add(new JLabel("DRIP power state:"), "");
        add(displayEnabledLabel, "wrap");

        repaint();
    }

    private class InternalPreviewPanel extends JPanel {

        public InternalPreviewPanel() {
        }

        @Override
        public void paint(Graphics g) {
            super.paint(g);

            final Graphics2D g2d = (Graphics2D)g;
            g2d.setColor(Color.BLACK);
            g2d.fillRect(0, 0, displayWidth, displayHeight);

            if (isDisplayEnabled) {
                g2d.drawImage(image, 0, 0, null);
            }
        }
    }

    public void dripChanged(int width, int height) {
        LOG.debug("dripChanged");

        displayWidth = width;
        displayHeight = height;
        Dimension size = new Dimension(displayWidth, displayHeight);
        ipp.setBackground(Color.RED);
        ipp.setMinimumSize(size);
        ipp.setPreferredSize(size);
        ipp.setSize(size);

        repaint();
    }

    @Override
    public void propertiesChanged(int displayAddress, TdpDisplayProperties properties) {
        dripChanged(properties.getDisplayWidthInPixels(), properties.getDisplayHeightInPixels());
    }

    @Override
    public void imageChanged(int displayAddress, BufferedImage image, boolean isDisplayEnabled) {
        this.image = image;
        this.isDisplayEnabled = isDisplayEnabled;

        displayEnabledLabel.setText(isDisplayEnabled ? "enabled" : "disabled");

        repaint();
    }
}
