/*
Copyright (c) 2013-2019, Technolution B.V.
 All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this 
   list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice, this 
   list of conditions and the following disclaimer in the documentation and/or 
   other materials provided with the distribution.

3. Neither the name of Technolution nor the names of its contributors may be used 
   to endorse or promote products derived from this software without specific 
   prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, 
OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
POSSIBILITY OF SUCH DAMAGE.
*/
package org.disperanto.displaysimulator.ui.panels;

import java.awt.event.ActionListener;

import javax.swing.ButtonGroup;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JSpinner;
import javax.swing.SpinnerNumberModel;
import javax.swing.event.ChangeListener;

import net.miginfocom.swing.MigLayout;

/**
 * Panel for showing images from image banks of display.
 */
public class ImagePanel extends JPanel {

    private FontPreviewPanel fontPreviewPanel = new FontPreviewPanel();

    private JRadioButton currentlyShownRadio;
    private JRadioButton imageSlotRadio;
    private JSpinner imageSlot;

    /**
     * Constructor
     */
    public ImagePanel() {
        initUI();
    }

    private void initUI() {
        setLayout(new MigLayout());

        currentlyShownRadio = new JRadioButton("Currently shown image");
        imageSlotRadio = new JRadioButton("Select imageslot to show: ");
        currentlyShownRadio.setSelected(true);
        ButtonGroup radioGroup = new ButtonGroup();
        radioGroup.add(currentlyShownRadio);
        radioGroup.add(imageSlotRadio);
        imageSlot = new JSpinner(new SpinnerNumberModel(0, 0, 999999, 1));

        add(fontPreviewPanel, "span 2, wrap");
        add(currentlyShownRadio, "wrap");
        add(imageSlotRadio);
        add(imageSlot, "width 50, wrap");
    }

    /**
     * Add listener for panel actions
     * 
     * @param listener Action listener
     */
    public final void addActionListener(ActionListener listener) {
        currentlyShownRadio.addActionListener(listener);
        imageSlotRadio.addActionListener(listener);
    }

    /**
     * Add listener for spinner changes
     * 
     * @param listener Change listener
     */
    public final void addChangeListener(ChangeListener listener) {
        imageSlot.addChangeListener(listener);
    }

    /**
     * @return the fontPreviewPanel
     */
    public final FontPreviewPanel getFontPreviewPanel() {
        return fontPreviewPanel;
    }

    /**
     * @return the imageSlot
     */
    public final JSpinner getImageSlot() {
        return imageSlot;
    }

    /**
     * @return the currentlyShownRadio
     */
    public final JRadioButton getCurrentlyShownRadio() {
        return currentlyShownRadio;
    }

    /**
     * @return the imageSlotRadio
     */
    public final JRadioButton getImageSlotRadio() {
        return imageSlotRadio;
    }
}
