/*
Copyright (c) 2013, Technolution B.V.
 All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this 
   list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice, this 
   list of conditions and the following disclaimer in the documentation and/or 
   other materials provided with the distribution.

3. Neither the name of Technolution nor the names of its contributors may be used 
   to endorse or promote products derived from this software without specific 
   prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, 
OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
POSSIBILITY OF SUCH DAMAGE.
*/
package org.disperanto.simulator.ui.models;

import java.util.LinkedList;

import javax.swing.table.AbstractTableModel;

import org.disperanto.simulator.data.LogEvent;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Model for logging information.
 */
public class LoggingModel extends AbstractTableModel {
    private static final Logger LOG = LoggerFactory.getLogger(LoggingModel.class);

    private final String[] columnNames = { "Date and time", "Description" };
    private final LinkedList<LogEvent> eventList = new LinkedList<LogEvent>();

    /**
     * Constructor
     */
    public LoggingModel() {
        super();
    }

    @Override
    public final int getColumnCount() {
        return columnNames.length;
    }

    @Override
    public final int getRowCount() {
        return eventList.size();
    }

    @Override
    public final String getColumnName(int col) {
        return columnNames[col];
    }

    @Override
    public final Object getValueAt(int rowIndex, int columnIndex) {

        if (columnIndex == 0) {
            return eventList.get(rowIndex).getDateTime();
        } else if (columnIndex == 1) {
            return eventList.get(rowIndex).getDescription();
        } else {
            throw new IllegalArgumentException("Unexpected column index (" + columnIndex + ")");
        }
    }

    /**
     * Add row to log table
     *
     * @param event Event to be added to table
     */
    public final void addRow(LogEvent event) {
        LOG.debug(event.getDescription());
        eventList.addFirst(event);
        fireTableDataChanged();
    }
}
