/*
Copyright (c) 2013-2019, Technolution B.V.
 All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this 
   list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice, this 
   list of conditions and the following disclaimer in the documentation and/or 
   other materials provided with the distribution.

3. Neither the name of Technolution nor the names of its contributors may be used 
   to endorse or promote products derived from this software without specific 
   prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, 
OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
POSSIBILITY OF SUCH DAMAGE.
*/
package org.disperanto.simulator.ui.panels;

import java.awt.event.ActionListener;

import javax.swing.BorderFactory;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JSpinner;
import javax.swing.SpinnerNumberModel;

import net.miginfocom.swing.MigLayout;

/**
 * Panel for command selection.
 */
public class CommandChoicePanel extends JPanel {
    // Components
    private JSpinner displayAddress;
    private JCheckBox displayPropertiesCheck;
    private JCheckBox statusCheck;
    private JCheckBox rebootCheck;
    private JCheckBox keepAliveCheck;
    private JCheckBox setCommunicationTimeoutCheck;
    private JCheckBox setBrightnessTableCheck;
    private JCheckBox setExternalLightingCheck;
    private JCheckBox diagnosticsCheck;
    private JCheckBox manipulateMemorySlotCheck;
    private JCheckBox calculateCrcCheck;
    private JCheckBox showNoImageCheck;
    private JCheckBox showImageCheck;
    private JCheckBox startSlideShowCheck;
    private JCheckBox serviceModeCheck;
    private JCheckBox clearNotificationsCheck;
    private JCheckBox setTextCheck;

    private JButton addButton;

    /**
     * Constructor
     */
    public CommandChoicePanel() {
        initUI();
    }

    /**
     * Add listener for panel actions
     *
     * @param listener Action listener
     */
    public final void addListener(ActionListener listener) {
        addButton.addActionListener(listener);
    }

    private void initUI() {
        setLayout(new MigLayout("", "[]20[]", ""));
        setBorder(BorderFactory.createTitledBorder("Command choice"));

        displayAddress = new JSpinner(new SpinnerNumberModel(6, 1, 255, 1));
        displayPropertiesCheck = new JCheckBox();
        statusCheck = new JCheckBox();
        rebootCheck = new JCheckBox();
        keepAliveCheck = new JCheckBox();
        setCommunicationTimeoutCheck = new JCheckBox();
        setBrightnessTableCheck = new JCheckBox();
        setExternalLightingCheck = new JCheckBox();
        diagnosticsCheck = new JCheckBox();
        manipulateMemorySlotCheck = new JCheckBox();
        calculateCrcCheck = new JCheckBox();
        showNoImageCheck = new JCheckBox();
        showImageCheck = new JCheckBox();
        startSlideShowCheck = new JCheckBox();
        serviceModeCheck = new JCheckBox();
        clearNotificationsCheck = new JCheckBox();
        setTextCheck = new JCheckBox();

        add(new JLabel("Display address:"));
        add(displayAddress, "wrap");

        add(new JLabel("Display properties:"));
        add(displayPropertiesCheck, "wrap");

        add(new JLabel("Status:"));
        add(statusCheck, "wrap");

        add(new JLabel("Reboot:"));
        add(rebootCheck, "wrap");

        add(new JLabel("Keep alive:"));
        add(keepAliveCheck, "wrap");

        add(new JLabel("Set communication timeout:"));
        add(setCommunicationTimeoutCheck, "wrap");

        add(new JLabel("Set brightness table:"));
        add(setBrightnessTableCheck, "wrap");

        add(new JLabel("Set external lighting:"));
        add(setExternalLightingCheck, "wrap");

        add(new JLabel("Diagnostics:"));
        add(diagnosticsCheck, "wrap");

        add(new JLabel("Manipulate memory slot:"));
        add(manipulateMemorySlotCheck, "wrap");

        add(new JLabel("Calculate CRC:"));
        add(calculateCrcCheck, "wrap");

        add(new JLabel("Show no image:"));
        add(showNoImageCheck, "wrap");

        add(new JLabel("Show image:"));
        add(showImageCheck, "wrap");

        add(new JLabel("Start slideshow:"));
        add(startSlideShowCheck, "wrap");

        add(new JLabel("Set text:"));
        add(setTextCheck, "wrap");

        add(new JLabel("Service mode:"));
        add(serviceModeCheck, "wrap");

        add(new JLabel("Clear notifications:"));
        add(clearNotificationsCheck, "wrap");

        addButton = new JButton("Add to send list");
        add(new JLabel());
        add(addButton, "wrap");
    }

    /**
     * @return the displayAddress
     */
    public final int getDisplayAddress() {
        return ((Integer)displayAddress.getValue()).intValue();
    }

    /**
     * @return the displayPropertiesCheck
     */
    public final JCheckBox getDisplayPropertiesCheck() {
        return displayPropertiesCheck;
    }

    /**
     * @return the statusCheck
     */
    public final JCheckBox getStatusCheck() {
        return statusCheck;
    }

    /**
     * @return the rebootCheck
     */
    public final JCheckBox getRebootCheck() {
        return rebootCheck;
    }

    /**
     * @return the keepAliveCheck
     */
    public final JCheckBox getKeepAliveCheck() {
        return keepAliveCheck;
    }

    /**
     * @return the setCommunicationTimeoutCheck
     */
    public final JCheckBox getSetCommunicationTimeoutCheck() {
        return setCommunicationTimeoutCheck;
    }

    /**
     * @return the setBrightnessTableCheck
     */
    public final JCheckBox getSetBrightnessTableCheck() {
        return setBrightnessTableCheck;
    }

    /**
     * @return the setExternalLightingCheck
     */
    public final JCheckBox getSetExternalLightingCheck() {
        return setExternalLightingCheck;
    }

    /**
     * @return the diagnosticsCheck
     */
    public final JCheckBox getDiagnosticsCheck() {
        return diagnosticsCheck;
    }

    /**
     * @return the manipulateMemorySlotCheck
     */
    public final JCheckBox getManipulateMemorySlotCheck() {
        return manipulateMemorySlotCheck;
    }

    /**
     * @return the calculateCrcCheck
     */
    public final JCheckBox getCalculateCrcCheck() {
        return calculateCrcCheck;
    }

    /**
     * @return the showNoImageCheck
     */
    public final JCheckBox getShowNoImageCheck() {
        return showNoImageCheck;
    }

    /**
     * @return the showImageCheck
     */
    public final JCheckBox getShowImageCheck() {
        return showImageCheck;
    }

    /**
     * @return the startSlideShowCheck
     */
    public final JCheckBox getStartSlideShowCheck() {
        return startSlideShowCheck;
    }

    /**
     * @return the setTextCheck
     */
    public final JCheckBox getSetTextCheck() {
        return setTextCheck;
    }

    /**
     * @return the serviceModeCheck
     */
    public final JCheckBox getServiceModeCheck() {
        return serviceModeCheck;
    }

    /**
     * @return the clearNotificationsCheck
     */
    public final JCheckBox getClearNotificationsCheck() {
        return clearNotificationsCheck;
    }
}
