/*
Copyright (c) 2013-2015, Technolution B.V.
 All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this
   list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice, this
   list of conditions and the following disclaimer in the documentation and/or
   other materials provided with the distribution.

3. Neither the name of Technolution nor the names of its contributors may be used
   to endorse or promote products derived from this software without specific
   prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
POSSIBILITY OF SUCH DAMAGE.
 */
package org.disperanto.simulator.ui.panels;

import java.awt.event.ActionListener;
import java.net.UnknownHostException;
import java.util.Vector;

import javax.swing.BorderFactory;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;

import net.miginfocom.swing.MigLayout;

import org.disperanto.communication.IStartableConnection;
import org.disperanto.communication.TcpSender;
import org.disperanto.communication.UdpSender;
import org.disperanto.enums.EIpConnectionType;
import org.disperanto.simulator.ui.components.NumericTextField;
import org.disperanto.simulator.ui.models.IConnectionModel;

/**
 * Panel for setting the connection .
 */
public class ConnectionPanel extends JPanel implements IConnectionModel {

    private JTextField urlField;
    private NumericTextField portField;
    private NumericTextField timeoutField;
    private JComboBox<EIpConnectionType> connectionTypeBox;

    private JButton applyButton;

    /**
     * Constructor
     */
    public ConnectionPanel() {
        initUI();
    }

    /**
     * Add listener for apply button.
     *
     * @param listener Action listener
     */
    public final void addListener(ActionListener listener) {
        applyButton.addActionListener(listener);
    }

    @Override
    public IStartableConnection getConnection() {
        EIpConnectionType type = (EIpConnectionType)connectionTypeBox.getSelectedItem();
        String url = urlField.getText();
        int port = (int)portField.getValue();
        int timeoutMs = (int)timeoutField.getValue();

        switch (type) {
        case UDP:
            try {
                return new UdpSender(url, port, timeoutMs);
            } catch (UnknownHostException e) {
                throw new RuntimeException(e);
            }
        case TCP:
            return new TcpSender(url, port, timeoutMs);
        default:
            assert false; // This is impossible, all cases covered.
            return null;
        }
    }

    private void initUI() {
        setLayout(new MigLayout());
        setBorder(BorderFactory.createTitledBorder("Connection settings"));

        add(new JLabel("Connection type:"));
        Vector<EIpConnectionType> options = new Vector<EIpConnectionType>(EIpConnectionType.getEnabled());
        connectionTypeBox = new JComboBox<EIpConnectionType>(options);
        connectionTypeBox.setSelectedItem(EIpConnectionType.TCP);
        add(connectionTypeBox, "gapright 10");

        urlField = new JTextField("127.0.0.1", 20);
        add(new JLabel("Display Controller address:"));
        add(urlField, "gapright 10");

        portField = new NumericTextField(3456, 1025, 0xFFFF);
        add(new JLabel("port:"));
        add(portField, "gapright 10");

        JLabel timeoutLabel = new JLabel("Timeout:");
        add(timeoutLabel);
        timeoutField = new NumericTextField(1000, 1, 86400);
        add(timeoutField, "gapright 10");

        applyButton = new JButton("Apply");
        add(applyButton);
    }

}
