/*
Copyright (c) 2013, Technolution B.V.
 All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this
   list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice, this
   list of conditions and the following disclaimer in the documentation and/or
   other materials provided with the distribution.

3. Neither the name of Technolution nor the names of its contributors may be used
   to endorse or promote products derived from this software without specific
   prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
POSSIBILITY OF SUCH DAMAGE.
 */
package org.disperanto.simulator.ui.panels;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Collection;

import javax.swing.BorderFactory;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;

import net.miginfocom.swing.MigLayout;

import org.disperanto.data.TdpTimeoutSettings;
import org.disperanto.enums.ETdpCommand;
import org.disperanto.enums.ETdpTimeoutMode;
import org.disperanto.simulator.ui.components.NumericTextField;
import org.disperanto.simulator.ui.models.ICommunicationTimeoutSettingsModel;

/**
 * Panel for communication timeout panelDatadata.
 */
public class DataCommunicationTimeoutPanel extends JPanel implements ICommunicationTimeoutSettingsModel {

    private JComboBox<ETdpTimeoutMode> modeBox;
    private NumericTextField timeoutField;
    private NumericTextField imageSlotField;

    public DataCommunicationTimeoutPanel() {
        super(new MigLayout("", "[align right][110]", "[]"));
        initUI();
    }

    @Override
    public TdpTimeoutSettings getTimeoutSettings() {
        TdpTimeoutSettings settings = new TdpTimeoutSettings();
        settings.setTimeoutMode((ETdpTimeoutMode)modeBox.getSelectedItem());
        settings.setTimeoutInSec((int)timeoutField.getValue());
        settings.setImageSlot((int)imageSlotField.getValue());
        return settings;
    }

    @Override
    public void commandListChanged(Collection<ETdpCommand> commands) {
        setComponentsEnabled(!commands.contains(ETdpCommand.SET_COMMUNICATION_TIMEOUT));
    }

    private void setComponentsEnabled(boolean enabled) {
        modeBox.setEnabled(enabled);
        timeoutField.setEnabled(enabled);
        imageSlotField.setEnabled(enabled);
    }

    private void initUI() {
        setBorder(BorderFactory.createTitledBorder("Communication timeout settings"));

        modeBox = new JComboBox<ETdpTimeoutMode>(ETdpTimeoutMode.values());
        modeBox.setSelectedItem(ETdpTimeoutMode.NO_TIMEOUT);
        modeBox.addActionListener(new ActionListener() {

            @Override
            public void actionPerformed(ActionEvent e) {
                updateGui();
            }
        });

        timeoutField = new NumericTextField(60);
        imageSlotField = new NumericTextField(0);

        add(new JLabel("Timeout mode: "));
        add(modeBox, "wrap");

        add(new JLabel("Timeout in seconds: "));
        add(timeoutField, "grow, wrap");

        add(new JLabel("ImageSlot: "));
        add(imageSlotField, "grow, wrap");

        updateGui();
    }

    private void updateGui() {
        timeoutField.setEnabled(modeBox.getSelectedItem() != ETdpTimeoutMode.NO_TIMEOUT);
        imageSlotField.setEnabled(modeBox.getSelectedItem() == ETdpTimeoutMode.SHOW_IMAGE);
    }
}
