/*
Copyright (c) 2013, Technolution B.V.
 All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this 
   list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice, this 
   list of conditions and the following disclaimer in the documentation and/or 
   other materials provided with the distribution.

3. Neither the name of Technolution nor the names of its contributors may be used 
   to endorse or promote products derived from this software without specific 
   prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, 
OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
POSSIBILITY OF SUCH DAMAGE.
*/
package org.disperanto.simulator.ui.panels;

import javax.swing.BorderFactory;
import javax.swing.JPanel;

import net.miginfocom.swing.MigLayout;

/**
 * Panel for showing the commands and responses being exchanged with the display.
 */
public class ExchangePanel extends JPanel {

    private final CommandChoicePanel commandChoicePanel = new CommandChoicePanel();
    private final CommandListPanel commandListPanel = new CommandListPanel();
    private final ResponseListPanel responseListPanel = new ResponseListPanel();

    /**
     * Constructor
     */
    public ExchangePanel() {
        initUI();
    }

    private void initUI() {
        setLayout(new MigLayout("", "[][grow][grow]", "[]"));
        setBorder(BorderFactory.createTitledBorder("Exchange messages"));

        add(commandChoicePanel, "grow");
        add(commandListPanel, "grow");
        add(responseListPanel, "grow");
    }

    /**
     * @return the commandChoicePanel
     */
    public final CommandChoicePanel getCommandChoicePanel() {
        return commandChoicePanel;
    }

    /**
     * @return the commandListPanel
     */
    public final CommandListPanel getCommandListPanel() {
        return commandListPanel;
    }

    /**
     * @return the responseListPanel
     */
    public final ResponseListPanel getResponseListPanel() {
        return responseListPanel;
    }
}
