/*
Copyright (c) 2013, Technolution B.V.
 All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this 
   list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice, this 
   list of conditions and the following disclaimer in the documentation and/or 
   other materials provided with the distribution.

3. Neither the name of Technolution nor the names of its contributors may be used 
   to endorse or promote products derived from this software without specific 
   prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, 
OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
POSSIBILITY OF SUCH DAMAGE.
*/
package org.disperanto.simulator.ui.panels;

import java.util.Collection;

import javax.swing.BorderFactory;
import javax.swing.JLabel;
import javax.swing.JPanel;

import org.disperanto.data.TdpShowImage;
import org.disperanto.enums.ETdpCommand;
import org.disperanto.simulator.ui.components.NumericTextField;
import org.disperanto.simulator.ui.models.IShowImageModel;

import net.miginfocom.swing.MigLayout;

/**
 * Panel showing the number of the image being showns.
 */
public class ShowImagePanel extends JPanel implements IShowImageModel {

    private final NumericTextField slotField;

    public ShowImagePanel() {
        super(new MigLayout("", "[grow, align right][110]", "[]"));
        setBorder(BorderFactory.createTitledBorder("Show image"));
        add(new JLabel("Slot number: "));
        slotField = new NumericTextField(2, 0, 999);
        add(slotField, "grow");
    }

    @Override
    public TdpShowImage getShowImage() {
        TdpShowImage showImage = new TdpShowImage();
        showImage.setImageSlot((int)slotField.getValue());
        return showImage;
    }

    @Override
    public void commandListChanged(Collection<ETdpCommand> commands) {
        setComponentsEnabled(!commands.contains(ETdpCommand.SHOW_IMAGE));
    }

    private void setComponentsEnabled(boolean enabled) {
        slotField.setEnabled(enabled);
    }
}
