/*
Copyright (c) 2013, Technolution B.V.
 All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this 
   list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice, this 
   list of conditions and the following disclaimer in the documentation and/or 
   other materials provided with the distribution.

3. Neither the name of Technolution nor the names of its contributors may be used 
   to endorse or promote products derived from this software without specific 
   prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, 
OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
POSSIBILITY OF SUCH DAMAGE.
*/
package org.disperanto.data;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

/**
 * Defines the brightness table of a display in Disperanto.
 */
public class TdpBrightnessTable implements Serializable {

    private List<Integer> brightnessTable = new ArrayList<Integer>();

    /**
     * Constructor
     */
    public TdpBrightnessTable() {
        // empty object
    }

    /**
     * Constructor
     */
    public TdpBrightnessTable(List<Integer> brightnessTable) {
        this.brightnessTable.addAll(brightnessTable);
    }

    /**
     * @return the brightnessTable
     */
    public final List<Integer> getBrightnessTable() {
        return brightnessTable;
    }

    /**
     * @param brightnessTable the brightnessTable to set, should contain 11(!) values, from 0% up to 100%
     */
    public final void setBrightnessTable(List<Integer> brightnessTable) {
        if (brightnessTable.size() != 11) {
            throw new IllegalStateException("Brightness table should contain 11 values, 0% up to 100%");
        }
        this.brightnessTable = brightnessTable;
    }

    @Override
    public final String toString() {
        final StringBuilder builder = new StringBuilder("Brightness table:");

        for (int i = 0; i < brightnessTable.size(); i++) {
            builder.append("\n\tBrightness at " + (i * 10) + "% measured intensity: " + brightnessTable.get(i));
        }

        return builder.toString();
    }
}
