/*
Copyright (c) 2013-2015, Technolution B.V.
 All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this 
   list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice, this 
   list of conditions and the following disclaimer in the documentation and/or 
   other materials provided with the distribution.

3. Neither the name of Technolution nor the names of its contributors may be used 
   to endorse or promote products derived from this software without specific 
   prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, 
OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
POSSIBILITY OF SUCH DAMAGE.
*/
package org.disperanto.data;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.disperanto.enums.ETdpNotification;


/**
 * Defines the notifications for a specific display of a specific host.
 */
public class TdpNotifications {

    private String host;
    private int displayAddress;
    private Map<ETdpNotification, TdpNotification> notifications = new HashMap<ETdpNotification, TdpNotification>();

    /**
     * Constructor
     */
    public TdpNotifications() {
        // empty object
    }

    /**
     * @param host the host to set
     */
    public final void setHost(String host) {
        this.host = host;
    }

    /**
     * @return the displayAddress
     */
    public final int getDisplayAddress() {
        return displayAddress;
    }

    /**
     * @param displayAddress Address of the display
     */
    public final void setDisplayAddress(int displayAddress) {
        this.displayAddress = displayAddress;
    }

    /**
     * @return the notifications
     */
    public final List<TdpNotification> getNotifications() {
        return new ArrayList<TdpNotification>(notifications.values());
    }

    /**
     * @param notifications List of notifications
     */
    public final void addNotifications(List<TdpNotification> notifications) {
        for (TdpNotification notification : notifications) {
            this.notifications.put(notification.getTag(), notification);
        }
    }

    @Override
    public final String toString() {
        final StringBuilder builder = new StringBuilder("Notification list: ");

        builder.append("\n\thost: ").append(host);
        builder.append("\n\tdisplay : ").append(displayAddress);
        if (!notifications.isEmpty()) {
            for (TdpNotification notification : notifications.values()) {
                builder.append("\n\t").append(notification.toString());
            }
        } else {
            builder.append("\n\tNo notifications present");
        }

        return builder.toString();
    }
}
