/*
Copyright (c) 2013, Technolution B.V.
 All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this 
   list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice, this 
   list of conditions and the following disclaimer in the documentation and/or 
   other materials provided with the distribution.

3. Neither the name of Technolution nor the names of its contributors may be used 
   to endorse or promote products derived from this software without specific 
   prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, 
OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
POSSIBILITY OF SUCH DAMAGE.
*/
package org.disperanto.enums;

import java.util.ArrayList;
import java.util.EnumSet;
import java.util.List;
import java.util.Set;

/**
 * Connection type used in Disperanto, i.e. whether the connection uses TCP, UDP, MDOT.
 */
public enum EIpConnectionType {

    TCP("tcp"),
    UDP("udp"),
    MOBITEX("mobitex");

    // by default, only tcp and udp are enabled
    private static Set<EIpConnectionType> enabled = EnumSet.of(EIpConnectionType.TCP, EIpConnectionType.UDP);

    private final String id;

    private EIpConnectionType(String id) {
        this.id = id;
    }

    public static boolean isEnabled(EIpConnectionType protocol) {
        return enabled.contains(protocol);
    }

    public static void setEnabled(Set<EIpConnectionType> protocols) {
        if (protocols.size() == 0) {
            throw new IllegalArgumentException("At least one TYPE must be supported:" + protocols);
        }
        enabled.clear();
        enabled.addAll(EnumSet.copyOf(protocols));
    }

    public static List<EIpConnectionType> getEnabled() {
        return new ArrayList<EIpConnectionType>(enabled);
    }

    /**
     * @return The enum constant corresponding to the given id, or null if not found.
     */
    public static EIpConnectionType fromId(String id) {
        for (EIpConnectionType type : EIpConnectionType.values()) {
            if (type.id.equals(id)) {
                return type;
            }
        }
        return null;
    }
}