/*
Copyright (c) 2013, Technolution B.V.
 All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this 
   list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice, this 
   list of conditions and the following disclaimer in the documentation and/or 
   other materials provided with the distribution.

3. Neither the name of Technolution nor the names of its contributors may be used 
   to endorse or promote products derived from this software without specific 
   prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, 
OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
POSSIBILITY OF SUCH DAMAGE.
*/
package org.disperanto.enums;

/**
 * Definition of tags of Display Property data in Disperanto.
 */
public enum ETdpDisplayProperties {

    PROTOCOL_VERSION(0x00, "ProtocolVersion"),
    DISPLAY_TYPE(0x01, "DisplayType"),
    SUPPLIER_AND_PRODUCTTYPE(0x02, "SupplierAndProductType"),
    SERIALNUMBER(0x03, "SerialNumber"),
    SOFTWARE_VERSION(0x04, "SoftwareVersion"),
    EXTERNAL_LIGHTING(0x05, "ExternalLighting"),
    DISPLAY_HEIGHT(0x10, "DisplayHeight"),
    DISPLAY_WIDTH(0x11, "DisplayWidth"),
    NR_FIXED_IMAGES(0x12, "NumberOfFixedImages"),
    NR_WRITABLE_IMAGES(0x13, "NumberOfWritableImages"),
    SLIDE_SHOW(0x14, "SlideShow"),
    RGB_COLORS(0x15, "RGBColors"),
    FIXED_COLOR_PALETTE(0x16, "FixedColorPalette"),
    PNG_SUPPORTED(0x17, "PNGSupported");


    /**
     * Numerical value of tag in protocol
     */
    private final int value;

    /**
     * Description of tag in protocol
     */
    private final String description;

    /**
     * Private constructor
     *
     * @param value Numerical value of tag in protocol
     * @param description Description of tag in protocol
     */
    private ETdpDisplayProperties(int value, String description) {
        this.value = value;
        this.description = description;
    }

    /**
     * @return Numerical value of tag in protocol
     */
    public int getValue() {
        return value;
    }

    /**
     * @return Description of data length definition in protocol
     */
    public String getDescription() {
        return description;
    }

    /**
     * Converts a value to a tag enum.
     *
     * @param value Numerical value of tag in protocol
     * @return enum with given value, or null if no enum constant was found with the given value.
     */
    public static ETdpDisplayProperties convertValue(int value) {
        for (ETdpDisplayProperties current : values()) {
            if (current.getValue() == value) {
                return current;
            }
        }

        return null;
    }
}
