/*
Copyright (c) 2013, Technolution B.V.
 All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this 
   list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice, this 
   list of conditions and the following disclaimer in the documentation and/or 
   other materials provided with the distribution.

3. Neither the name of Technolution nor the names of its contributors may be used 
   to endorse or promote products derived from this software without specific 
   prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, 
OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
POSSIBILITY OF SUCH DAMAGE.
*/
package org.disperanto.enums;

/**
 * Different notifications that can be send in Disperanto.
 */
public enum ETdpNotification {

    COMMUNICATION_ERROR(1, "Communication error", false),
    SOFTWARE_FAILURE(2, "Software failure", false),
    HARDWARE_FAILURE(3, "Hardware failure", false),
    COLD_RESTART(4, "Cold restart", true),
    WARM_RESTART(5, "Warm restart", true),
    COMMUNICATION_TIMEOUT(6, "Communication timeout", true),
    NON_CRITICAL_DISPLAY_DEFECT(7, "Non critical display defect", false),
    CRITICAL_DISPLAY_DEFECT(8, "Critical display defect", false),
    INTRUSION(9, "Intrusion", true),
    EXTERNAL_LIGHTING_DEFECT(10, "External lighting defect", false),
    HEATING_DEFECT(11, "Heating defect", false),
    COOLING_DEFECT(12, "Cooling defect", false),
    TEMPERATURE_LOW(13, "Temperature low", false),
    TEMPERATURE_HIGH(14, "Temperature high", false),
    LUMINANCE_SENSOR_DEFECT(15, "Luminance sensor defect", false);

    /**
     * Numerical value of notification in protocol
     */
    private final int value;

    /**
     * Message of notification in protocol
     */
    private final String message;

    /**
     * True if notification is send until it is confirmed
     */
    private final boolean needsConfirm;

    /**
     * Private constructor
     *
     * @param value Numerical value of notification in protocol
     * @param message Message of notification in protocol
     */
    private ETdpNotification(int value, String message, boolean needsConfirm) {
        this.value = value;
        this.message = message;
        this.needsConfirm = needsConfirm;
    }

    /**
     * @return Numerical value of notification in protocol
     */
    public int getValue() {
        return value;
    }

    /**
     * @return Message of notification in protocol
     */
    public String getMessage() {
        return message;
    }

    /**
     * @return true if notification should be confirmed
     */
    public boolean isNeedsConfirm() {
        return needsConfirm;
    }

    /**
     * Converts a value to a Disperanto notification enum.
     *
     * @param value Numerical value of notification in protocol
     * @return Notification enum with given value, or null if no enum constant was found with the given value.
     */
    public static ETdpNotification convertValue(int value) {
        for (ETdpNotification current : values()) {
            if (current.getValue() == value) {
                return current;
            }
        }

        return null;
    }
}
