/*
Copyright (c) 2013, Technolution B.V.
 All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this 
   list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice, this 
   list of conditions and the following disclaimer in the documentation and/or 
   other materials provided with the distribution.

3. Neither the name of Technolution nor the names of its contributors may be used 
   to endorse or promote products derived from this software without specific 
   prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, 
OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
POSSIBILITY OF SUCH DAMAGE.
*/
package org.disperanto.messages;

import java.nio.ByteBuffer;

import org.disperanto.data.TdpDiagnostics;
import org.disperanto.enums.ETdpCommand;
import org.disperanto.exception.TdpProtocolException;
import org.disperanto.utils.VlqUtils;


/**
 * Formatter for the Diagnostics response.
 */
public final class DiagnosticsResponse {
    /**
     * Constructor
     */
    private DiagnosticsResponse() {
        // Empty constructor
    }

    /**
     * Creates the data buffer for the Diagnostics response.<br>
     *
     * Data only contains a human readable string.
     *
     * @param diagnostics Data of this response message
     * @return Data buffer for the brightness percentages
     */
    public static ByteBuffer createData(TdpDiagnostics diagnostics) {
        final TdpFormatter formatter = new TdpFormatter();

        // buffer length is number of VLQ-bytes + length of string
        final ByteBuffer settingsData = ByteBuffer.allocate(VlqUtils.countVlqBytes(diagnostics.getMessage().length()) +
                diagnostics.getMessage().length());

        settingsData.put(formatter.setStringData(diagnostics.getMessage(), 1024, "message",
                ETdpCommand.DIAGNOSTICS.getName()));

        return settingsData;
    }

    /**
     * Parses the received data to a TdpDiagnostics object <br>
     *
     * @param message Generic message that is received from a display
     * @return Diagnostics of a display in the Disperanto
     */
    public static TdpDiagnostics parse(TdpMessage message) throws TdpProtocolException {
        final TdpFormatter formatter = new TdpFormatter();
        final TdpDiagnostics diagnostics = new TdpDiagnostics();

        formatter.checkResponse(message, ETdpCommand.DIAGNOSTICS);

        // Parse data
        final ByteBuffer data = formatter.getMessageData(message);

        diagnostics.setMessage(formatter.parseStringData(data, data.capacity(), "message",
                ETdpCommand.DIAGNOSTICS.getName()));

        return diagnostics;
    }
}
