/*
Copyright (c) 2013, Technolution B.V.
 All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this 
   list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice, this 
   list of conditions and the following disclaimer in the documentation and/or 
   other materials provided with the distribution.

3. Neither the name of Technolution nor the names of its contributors may be used 
   to endorse or promote products derived from this software without specific 
   prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, 
OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
POSSIBILITY OF SUCH DAMAGE.
*/
package org.disperanto.messages;

import java.nio.ByteBuffer;

import org.disperanto.data.TdpShowImage;
import org.disperanto.enums.ETdpCommand;
import org.disperanto.exception.TdpProtocolException;
import org.disperanto.utils.ByteBufferUtils;
import org.disperanto.utils.VlqUtils;


/**
 * Formatter for the ShowImage command.
 */
public final class ShowImageCommand {

    /**
     * Constructor
     */
    private ShowImageCommand() {
        // Empty constructor
    }

    /**
     * Creates the data buffer for the ShowImage command.
     *
     * @param showImageSettings Data of this command message
     * @return Data buffer for the timeout settings
     */
    public static ByteBuffer createData(TdpShowImage showImageSettings) {
        final ByteBuffer settingsData = ByteBuffer.allocate(VlqUtils.MAX_VLQ_BYTES);

        settingsData.put(VlqUtils.getVlqBytes(showImageSettings.getImageSlot()));

        return ByteBufferUtils.truncateAtCurrentPosition(settingsData);
    }

    /**
     * Parses the received data to a TdpShowImage object
     *
     * @param message Generic message that is received from a display
     * @return Timeout settings of the Disperanto
     */
    public static TdpShowImage parse(TdpMessage message) throws TdpProtocolException {
        final TdpFormatter formatter = new TdpFormatter();
        final TdpShowImage showImageSettings = new TdpShowImage();

        formatter.checkCommand(message, ETdpCommand.SHOW_IMAGE);

        // Parse data
        final ByteBuffer data = formatter.getMessageData(message);

        showImageSettings.setImageSlot(VlqUtils.parseVlqData(data));

        formatter.checkRemainingData(data);

        return showImageSettings;
    }
}
