/*
Copyright (c) 2013, Technolution B.V.
 All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this 
   list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice, this 
   list of conditions and the following disclaimer in the documentation and/or 
   other materials provided with the distribution.

3. Neither the name of Technolution nor the names of its contributors may be used 
   to endorse or promote products derived from this software without specific 
   prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, 
OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
POSSIBILITY OF SUCH DAMAGE.
*/
package org.disperanto.refapp.displaycontroller;

import java.util.ArrayList;
import java.util.List;

import org.disperanto.data.TdpDisplayProperties;
import org.disperanto.data.TdpNotification;
import org.disperanto.data.TdpStatus;


/**
 * Stub for a display on a sign post.
 */
public class Display {
    private final int address;
    private TdpDisplayProperties displayProperties;
    private TdpStatus status;
    private final List<TdpNotification> notifications = new ArrayList<TdpNotification>();

    /**
     * Constructor
     *
     * @param address identification of the display on the sign post
     */
    public Display(int address) {
        this.address = address;
    }

    /**
     * @return the address
     */
    public final int getAddress() {
        return address;
    }

    /**
     * @return the displayProperties
     */
    public final TdpDisplayProperties getDisplayProperties() {
        return displayProperties;
    }

    /**
     * @param displayProperties the displayProperties to set
     */
    public final void setDisplayProperties(TdpDisplayProperties displayProperties) {
        this.displayProperties = displayProperties;
    }

    /**
     * @return the status
     */
    public final TdpStatus getStatus() {
        return status;
    }

    /**
     * @param status the status to set
     */
    public final void setStatus(TdpStatus status) {
        this.status = status;
    }

    /**
     * @return the notifications
     */
    public final List<TdpNotification> getNotifications() {
        return notifications;
    }

    /**
     * @param notification Notification to add to list
     */
    public final void addNotifications(TdpNotification notification) {
        notifications.add(notification);
    }

    /**
     * clear all notifications
     */
    public final void clearNotifications() {
        notifications.clear();
    }
}
