/*
Copyright (c) 2013, Technolution B.V.
 All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this 
   list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice, this 
   list of conditions and the following disclaimer in the documentation and/or 
   other materials provided with the distribution.

3. Neither the name of Technolution nor the names of its contributors may be used 
   to endorse or promote products derived from this software without specific 
   prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, 
OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
POSSIBILITY OF SUCH DAMAGE.
*/
package org.disperanto.utils;

import java.nio.ByteBuffer;

import org.disperanto.enums.ETdpDisplayProperties;
import org.junit.Assert;
import org.junit.Test;

/**
 * JUnit tests for class CompactTlvWriter.
 */
public class CompactTlvWriterTest {
    private static final byte FIRST_BYTE = (byte)0xF0;
    private static final byte SECOND_BYTE = (byte)0xFF;
    private static final byte THIRD_BYTE = (byte)0x0F;

    private CompactTlvWriter writer;

    /**
     * Test the function getDataLength()
     */
    @Test
    public final void testAdd() {
        // no data
        writer = new CompactTlvWriter(1);
        writer.add((byte)ETdpDisplayProperties.DISPLAY_HEIGHT.getValue(), null);
        final ByteBuffer writeBuffer1 = writer.getData();
        Assert.assertEquals((byte)0x10, writeBuffer1.get());

        // one data byte
        final ByteBuffer data1 = ByteBuffer.allocate(1);
        data1.put(FIRST_BYTE);

        writer = new CompactTlvWriter(2);
        writer.add((byte)ETdpDisplayProperties.DISPLAY_TYPE.getValue(), data1);
        final ByteBuffer writeBuffer2 = writer.getData();
        Assert.assertEquals((byte)0x41, writeBuffer2.get());
        Assert.assertEquals(FIRST_BYTE, writeBuffer2.get());

        // two data bytes
        final ByteBuffer data2 = ByteBuffer.allocate(2);
        data2.put(FIRST_BYTE);
        data2.put(SECOND_BYTE);

        writer = new CompactTlvWriter(3);
        writer.add((byte)ETdpDisplayProperties.EXTERNAL_LIGHTING.getValue(), data2);
        final ByteBuffer writeBuffer3 = writer.getData();
        Assert.assertEquals((byte)0x85, writeBuffer3.get());
        Assert.assertEquals(FIRST_BYTE, writeBuffer3.get());
        Assert.assertEquals(SECOND_BYTE, writeBuffer3.get());

        // three data bytes
        final ByteBuffer data3 = ByteBuffer.allocate(3);
        data3.put(FIRST_BYTE);
        data3.put(SECOND_BYTE);
        data3.put(THIRD_BYTE);

        writer = new CompactTlvWriter(5);
        writer.add((byte)ETdpDisplayProperties.PROTOCOL_VERSION.getValue(), data3);
        final ByteBuffer writeBuffer4 = writer.getData();
        Assert.assertEquals((byte)0xC0, writeBuffer4.get());
        Assert.assertEquals((byte)0x03, writeBuffer4.get());
        Assert.assertEquals(FIRST_BYTE, writeBuffer4.get());
        Assert.assertEquals(SECOND_BYTE, writeBuffer4.get());
        Assert.assertEquals(THIRD_BYTE, writeBuffer4.get());
    }
}
