/*
Copyright (c) 2013, Technolution B.V.
 All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this 
   list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice, this 
   list of conditions and the following disclaimer in the documentation and/or 
   other materials provided with the distribution.

3. Neither the name of Technolution nor the names of its contributors may be used 
   to endorse or promote products derived from this software without specific 
   prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, 
OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
POSSIBILITY OF SUCH DAMAGE.
*/
package org.disperanto.utils;

import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.image.BufferedImage;
import java.nio.ByteBuffer;

import org.junit.Assert;
import org.junit.Test;

/**
 * JUnit tests for class TdpUtils.
 */
public class TdpUtilsTest {

    /**
     * Tests the function calculateCrc()
     */
    @Test
    public final void testCalculateCrcBufferedImage() {
        // an empty image should return 0
        short crc = TdpUtils.calculateCrc((BufferedImage)null);
        Assert.assertEquals(-1, crc);
        
        // calculate the crc for an image
        BufferedImage image = new BufferedImage(100, 100, BufferedImage.TYPE_INT_RGB);
        Graphics2D g2d = image.createGraphics();
        g2d.setColor(Color.RED);
        g2d.fillRect(0, 0, 50, 50);
        g2d.dispose();
        crc = TdpUtils.calculateCrc(image);
        Assert.assertEquals(0x60D8, crc);
    }
    
    /**
     * Tests the function calculateCrc()
     */
    @Test
    public final void testCalculateCrc() {
        final String str = "123456789";

        // Allocate two bytes more than the string length.
        // The used buffer in the code already has two bytes reserved for the CRC.
        // These bytes must not be included in the CRC calculation.
        final ByteBuffer buffer = ByteBuffer.allocate(11);
        buffer.put(str.getBytes());
        final short crc = TdpUtils.calculateCrc(buffer.array());
        Assert.assertEquals(0x29B1, crc);
    }

    /**
     * Test the function toByteString()
     */
    @Test
    public final void testToByteString() {
        final ByteBuffer buffer = ByteBuffer.allocate(3);
        buffer.put((byte)0x01);
        buffer.put((byte)0x02);
        buffer.put((byte)0x03);

        final String s = ByteBufferUtils.toByteString(buffer);
        Assert.assertEquals("01 02 03 ", s);
    }
}
